# Slot: subclass_of


Constraint on the range of a property

URI: [http://w3id.org/biolink/biolinkml/meta/range_subclass](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
